<?php
// t@C쐬
$filename = $MOWIKI_DATA.encode($gIn['title']).'.txt';

// t@C̑݃`FbN
if (file_exists($filename)) {
  // ݂ĂȂǂݍ
  $fp = fopen($filename, 'r');
  while(!feof($fp)) {
	$contents .= fgets($fp, 1024);
  }
  fclose($fp);
}

// y[WҏWʂ\
$gOut['body'] = '<form method=POST action='.$_SERVER['PHP_SELF'].'>'
. $gIn['title'].'<br>'
.'<input name="ts" type="hidden" value="'.time().'">'
.'<input name="title" type="hidden" value="'.$gIn['title'].'">'
. '<textarea name="body" cols="20" rows="5">'.$contents.'</textarea><br>'
. '<input type="submit" value="쐬">'
// . '<input type="hidden" name="a" value="'.$gIn['a'].'"></form>'
. '<input type="hidden" name="a" value="S"></form>'

?>